==> qmmp-plugin-pack-0.8.6.tar.bz2: qmmp-plugin-pack-0.8.6/src/Input/mpg123/translations/mpg123_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>DecoderMPG123Factory</name>
    <message>
        <location filename="../decodermpg123factory.cpp" line="111"/>
        <source>MPG123 Plugin</source>
        <translation>Suplemento MPG123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="114"/>
        <source>MPEG Files</source>
        <translation>Ficheiros MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="254"/>
        <source>About MPG123 Audio Plugin</source>
        <translation>Sobre o suplemento MPG123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="255"/>
        <source>Qmmp MPG123 Audio Plugin</source>
        <translation>Suplemento Qmmp MPG123 Audio</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="256"/>
        <source>This plugin provides MPEG v1/2 layer1/2/3 support
with use of libmpg123 library</source>
        <translation>Este suplemento disponibiliza o suporte a ficheiros MPEG v1/2/3
através da biblioteca libmpg123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="258"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="70"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Sample rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <location filename="../mpegmetadatamodel.cpp" line="81"/>
        <location filename="../mpegmetadatamodel.cpp" line="84"/>
        <location filename="../mpegmetadatamodel.cpp" line="87"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="90"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="91"/>
        <source>File size</source>
        <translation>Tamanho de ficheiro</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <source>Protection</source>
        <translation>Proteção</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>Definições MPEG</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Tag Priority</source>
        <translation>Prioridade das tags</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>First:</source>
        <translation>Primeiro:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <location filename="../settingsdialog.ui" line="110"/>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <location filename="../settingsdialog.ui" line="115"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <location filename="../settingsdialog.ui" line="120"/>
        <location filename="../settingsdialog.ui" line="169"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <location filename="../settingsdialog.ui" line="125"/>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Disabled</source>
        <translation>Inativa</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Second:</source>
        <translation>Segundo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Third:</source>
        <translation>Terceiro:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="198"/>
        <source>Encodings</source>
        <translation>Codificação</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="210"/>
        <source>ID3v1 encoding:</source>
        <translation>Codificação ID3v1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="236"/>
        <source>ID3v2 encoding:</source>
        <translation>Codificação ID3v2:</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-0.9.3.tar.bz2: qmmp-plugin-pack-0.9.3/src/Input/mpg123/translations/mpg123_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>DecoderMPG123Factory</name>
    <message>
        <location filename="../decodermpg123factory.cpp" line="111"/>
        <source>MPG123 Plugin</source>
        <translation>Suplemento MPG123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="114"/>
        <source>MPEG Files</source>
        <translation>Ficheiros MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="271"/>
        <source>About MPG123 Audio Plugin</source>
        <translation>Sobre o suplemento MPG123 Audio</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="272"/>
        <source>Qmmp MPG123 Audio Plugin</source>
        <translation>Suplemento Qmmp MPG123 Audio</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="273"/>
        <source>This plugin provides MPEG v1/2 layer1/2/3 support
with use of libmpg123 library</source>
        <translation>Este suplemento disponibiliza o suporte a ficheiros
MPEG v1/2/3 através da biblioteca libmpg123</translation>
    </message>
    <message>
        <location filename="../decodermpg123factory.cpp" line="275"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="70"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Sample rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <location filename="../mpegmetadatamodel.cpp" line="81"/>
        <location filename="../mpegmetadatamodel.cpp" line="84"/>
        <location filename="../mpegmetadatamodel.cpp" line="87"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="90"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="91"/>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <source>Protection</source>
        <translation>Proteção</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Tag Priority</source>
        <translation>Prioridade das etiquetas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>First:</source>
        <translation>Primeiro:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <location filename="../settingsdialog.ui" line="110"/>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <location filename="../settingsdialog.ui" line="115"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <location filename="../settingsdialog.ui" line="120"/>
        <location filename="../settingsdialog.ui" line="169"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <location filename="../settingsdialog.ui" line="125"/>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Disabled</source>
        <translation>Inativa</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Second:</source>
        <translation>Segundo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Third:</source>
        <translation>Terceiro:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="198"/>
        <source>Encodings</source>
        <translation>Codificação</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="210"/>
        <source>ID3v1 encoding:</source>
        <translation>Codificação ID3v1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="236"/>
        <source>ID3v2 encoding:</source>
        <translation>Codificação ID3v2:</translation>
    </message>
</context>
</TS>
